@@ -46,7 +46,7 @@ namespace Kleo {
 namespace Kleo {
 
   class KDE_EXPORT KeyFilterManager : public TQObject {
-    Q_OBJECT
+    TQ_OBJECT
   
   protected:
     KeyFilterManager( TQObject * parent=0, const char * name=0 );
