@@ -43,7 +43,7 @@ class CryptoConfigEntry;
 
 class KDE_EXPORT DirectoryServicesWidget : public DirectoryServicesWidgetBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
