@@ -38,7 +38,7 @@ class ConfigureWidget;
 
 class KDE_EXPORT ExtensionWidget : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
