@@ -82,7 +82,7 @@ typedef struct {
 
 class KDE_EXPORT KABCore : public KAB::Core
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
@@ -293,38 +293,38 @@ class KDE_EXPORT KABCore : public KAB::Core
     void contactModified( const TDEABC::Addressee &addr );
 
     /**
-      DCOP METHOD: Adds the given email address to address book.
+      DCOP method: Adds the given email address to address book.
      */
     virtual void addEmail( const TQString& addr );
 
     /**
-      DCOP METHOD: Imports the vCard, located at the given url.
+      DCOP method: Imports the vCard, located at the given url.
      */
     virtual void importVCard( const KURL& url );
 
     /**
-      DCOP METHOD: Imports the given vCard.
+      DCOP method: Imports the given vCard.
      */
     virtual void importVCardFromData( const TQString& vCard );
 
     /**
-      DCOP METHOD: Opens contact editor to input a new contact.
+      DCOP method: Opens contact editor to input a new contact.
      */
     virtual void newContact();
 
     /**
-     DCOP METHOD: Opens distribution list editor to create a new distribution list
+     DCOP method: Opens distribution list editor to create a new distribution list
     */
     virtual void newDistributionList();
 
     /**
-      DCOP METHOD: Returns the name of the contact, that matches the given
+      DCOP method: Returns the name of the contact, that matches the given
                    phone number.
      */
     virtual TQString getNameByPhone( const TQString& phone );
 
     /**
-      DCOP METHOD: Handle command line arguments, return true if handled
+      DCOP method: Handle command line arguments, return true if handled
       and false if no args was given. The iface is either the mainwin or the part.
      */
     bool handleCommandLine( KAddressBookIface* iface );
