@@ -47,7 +47,7 @@ KCMKabConfig::KCMKabConfig( TQWidget *parent, const char *name )
   mConfigWidget = new KABConfigWidget( this, "mConfigWidget" );
   layout->addWidget( mConfigWidget );
 
-  connect( mConfigWidget, TQT_SIGNAL( changed( bool ) ), TQT_SIGNAL( changed( bool ) ) );
+  connect( mConfigWidget, TQ_SIGNAL( changed( bool ) ), TQ_SIGNAL( changed( bool ) ) );
 
   load();
 
