@@ -353,11 +353,11 @@ void AccountDialog::makeLocalAccountPage()
 
   TQPushButton *choose = new TQPushButton( i18n("Choo&se..."), page );
   choose->setAutoDefault( false );
-  connect( choose, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotLocationChooser()) );
+  connect( choose, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotLocationChooser()) );
   topLayout->addWidget( choose, 3, 2 );
 
   TQButtonGroup *group = new TQButtonGroup(i18n("Locking Method"), page );
-  group->setColumnLayout(0, Qt::Horizontal);
+  group->setColumnLayout(0, TQt::Horizontal);
   group->layout()->setSpacing( 0 );
   group->layout()->setMargin( 0 );
   TQGridLayout *groupLayout = new TQGridLayout( group->layout() );
@@ -373,8 +373,8 @@ void AccountDialog::makeLocalAccountPage()
   mLocal.procmailLockFileName->insertStringList(procmailrcParser.getLockFilesList());
   mLocal.procmailLockFileName->setEnabled(false);
 
-  TQObject::connect(mLocal.lockProcmail, TQT_SIGNAL(toggled(bool)),
-                   mLocal.procmailLockFileName, TQT_SLOT(setEnabled(bool)));
+  TQObject::connect(mLocal.lockProcmail, TQ_SIGNAL(toggled(bool)),
+                   mLocal.procmailLockFileName, TQ_SLOT(setEnabled(bool)));
 
   mLocal.lockMutt = new TQRadioButton(
     i18n("&Mutt dotlock"), group);
@@ -404,19 +404,19 @@ void AccountDialog::makeLocalAccountPage()
   TQWhatsThis::add( mLocal.resourceClearButton,
                    i18n( "Delete all allocations for the resource represented by this account." ) );
   mLocal.resourceClearButton->setEnabled( false );
-  connect( mLocal.resourceCheck, TQT_SIGNAL( toggled(bool) ),
-           mLocal.resourceClearButton, TQT_SLOT( setEnabled(bool) ) );
-  connect( mLocal.resourceClearButton, TQT_SIGNAL( clicked() ),
-           this, TQT_SLOT( slotClearResourceAllocations() ) );
+  connect( mLocal.resourceCheck, TQ_SIGNAL( toggled(bool) ),
+           mLocal.resourceClearButton, TQ_SLOT( setEnabled(bool) ) );
+  connect( mLocal.resourceClearButton, TQ_SIGNAL( clicked() ),
+           this, TQ_SLOT( slotClearResourceAllocations() ) );
   mLocal.resourceClearPastButton =
       new TQPushButton( i18n( "Clear Past" ), resourceHB );
   mLocal.resourceClearPastButton->setEnabled( false );
-  connect( mLocal.resourceCheck, TQT_SIGNAL( toggled(bool) ),
-           mLocal.resourceClearPastButton, TQT_SLOT( setEnabled(bool) ) );
+  connect( mLocal.resourceCheck, TQ_SIGNAL( toggled(bool) ),
+           mLocal.resourceClearPastButton, TQ_SLOT( setEnabled(bool) ) );
   TQWhatsThis::add( mLocal.resourceClearPastButton,
                    i18n( "Delete all outdated allocations for the resource represented by this account." ) );
-  connect( mLocal.resourceClearPastButton, TQT_SIGNAL( clicked() ),
-           this, TQT_SLOT( slotClearPastResourceAllocations() ) );
+  connect( mLocal.resourceClearPastButton, TQ_SIGNAL( clicked() ),
+           this, TQ_SLOT( slotClearPastResourceAllocations() ) );
   topLayout->addMultiCellWidget( resourceHB, 5, 5, 0, 2 );
 #endif
 
@@ -428,8 +428,8 @@ void AccountDialog::makeLocalAccountPage()
   mLocal.intervalCheck =
     new TQCheckBox( i18n("Enable &interval mail checking"), page );
   topLayout->addMultiCellWidget( mLocal.intervalCheck, 6, 6, 0, 2 );
-  connect( mLocal.intervalCheck, TQT_SIGNAL(toggled(bool)),
-	   this, TQT_SLOT(slotEnableLocalInterval(bool)) );
+  connect( mLocal.intervalCheck, TQ_SIGNAL(toggled(bool)),
+	   this, TQ_SLOT(slotEnableLocalInterval(bool)) );
   mLocal.intervalLabel = new TQLabel( i18n("Check inter&val:"), page );
   topLayout->addWidget( mLocal.intervalLabel, 7, 0 );
   mLocal.intervalSpin = new KIntNumInput( page );
@@ -457,7 +457,7 @@ void AccountDialog::makeLocalAccountPage()
   mLocal.identityLabel->setBuddy( mLocal.identityCombo );
   topLayout->addWidget( mLocal.identityCombo, 10, 1 );
 
-  connect(kapp,TQT_SIGNAL(tdedisplayFontChanged()),TQT_SLOT(slotFontChanged()));
+  connect(kapp,TQ_SIGNAL(tdedisplayFontChanged()),TQ_SLOT(slotFontChanged()));
 }
 
 void AccountDialog::makeMaildirAccountPage()
@@ -492,7 +492,7 @@ void AccountDialog::makeMaildirAccountPage()
 
   TQPushButton *choose = new TQPushButton( i18n("Choo&se..."), page );
   choose->setAutoDefault( false );
-  connect( choose, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotMaildirChooser()) );
+  connect( choose, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotMaildirChooser()) );
   topLayout->addWidget( choose, 3, 2 );
 
 #if 0
@@ -503,21 +503,21 @@ void AccountDialog::makeMaildirAccountPage()
   mMaildir.resourceClearButton =
       new TQPushButton( i18n( "Clear" ), resourceHB );
   mMaildir.resourceClearButton->setEnabled( false );
-  connect( mMaildir.resourceCheck, TQT_SIGNAL( toggled(bool) ),
-           mMaildir.resourceClearButton, TQT_SLOT( setEnabled(bool) ) );
+  connect( mMaildir.resourceCheck, TQ_SIGNAL( toggled(bool) ),
+           mMaildir.resourceClearButton, TQ_SLOT( setEnabled(bool) ) );
   TQWhatsThis::add( mMaildir.resourceClearButton,
                    i18n( "Delete all allocations for the resource represented by this account." ) );
-  connect( mMaildir.resourceClearButton, TQT_SIGNAL( clicked() ),
-           this, TQT_SLOT( slotClearResourceAllocations() ) );
+  connect( mMaildir.resourceClearButton, TQ_SIGNAL( clicked() ),
+           this, TQ_SLOT( slotClearResourceAllocations() ) );
   mMaildir.resourceClearPastButton =
       new TQPushButton( i18n( "Clear Past" ), resourceHB );
   mMaildir.resourceClearPastButton->setEnabled( false );
-  connect( mMaildir.resourceCheck, TQT_SIGNAL( toggled(bool) ),
-           mMaildir.resourceClearPastButton, TQT_SLOT( setEnabled(bool) ) );
+  connect( mMaildir.resourceCheck, TQ_SIGNAL( toggled(bool) ),
+           mMaildir.resourceClearPastButton, TQ_SLOT( setEnabled(bool) ) );
   TQWhatsThis::add( mMaildir.resourceClearPastButton,
                    i18n( "Delete all outdated allocations for the resource represented by this account." ) );
-  connect( mMaildir.resourceClearPastButton, TQT_SIGNAL( clicked() ),
-           this, TQT_SLOT( slotClearPastResourceAllocations() ) );
+  connect( mMaildir.resourceClearPastButton, TQ_SIGNAL( clicked() ),
+           this, TQ_SLOT( slotClearPastResourceAllocations() ) );
   topLayout->addMultiCellWidget( resourceHB, 4, 4, 0, 2 );
 #endif
 
@@ -528,8 +528,8 @@ void AccountDialog::makeMaildirAccountPage()
   mMaildir.intervalCheck =
     new TQCheckBox( i18n("Enable &interval mail checking"), page );
   topLayout->addMultiCellWidget( mMaildir.intervalCheck, 5, 5, 0, 2 );
-  connect( mMaildir.intervalCheck, TQT_SIGNAL(toggled(bool)),
-	   this, TQT_SLOT(slotEnableMaildirInterval(bool)) );
+  connect( mMaildir.intervalCheck, TQ_SIGNAL(toggled(bool)),
+	   this, TQ_SLOT(slotEnableMaildirInterval(bool)) );
   mMaildir.intervalLabel = new TQLabel( i18n("Check inter&val:"), page );
   topLayout->addWidget( mMaildir.intervalLabel, 6, 0 );
   mMaildir.intervalSpin = new KIntNumInput( page );
@@ -557,7 +557,7 @@ void AccountDialog::makeMaildirAccountPage()
   mMaildir.identityLabel->setBuddy( mMaildir.identityCombo );
   topLayout->addWidget( mMaildir.identityCombo, 9, 1 );
 
-  connect(kapp,TQT_SIGNAL(tdedisplayFontChanged()),TQT_SLOT(slotFontChanged()));
+  connect(kapp,TQ_SIGNAL(tdedisplayFontChanged()),TQ_SLOT(slotFontChanged()));
 }
 
 
@@ -618,7 +618,7 @@ void AccountDialog::makePopAccountPage()
   label = new TQLabel( i18n("&Port:"), page1 );
   grid->addWidget( label, 4, 0 );
   mPop.portEdit = new KLineEdit( page1 );
-  mPop.portEdit->setValidator( new TQIntValidator(TQT_TQOBJECT(this)) );
+  mPop.portEdit->setValidator( new TQIntValidator(this) );
   label->setBuddy( mPop.portEdit );
   grid->addWidget( mPop.portEdit, 4, 1 );
 
@@ -638,19 +638,19 @@ void AccountDialog::makePopAccountPage()
 
   mPop.leaveOnServerCheck =
     new TQCheckBox( i18n("Lea&ve fetched messages on the server"), page1 );
-  connect( mPop.leaveOnServerCheck, TQT_SIGNAL( clicked() ),
-           this, TQT_SLOT( slotLeaveOnServerClicked() ) );
+  connect( mPop.leaveOnServerCheck, TQ_SIGNAL( clicked() ),
+           this, TQ_SLOT( slotLeaveOnServerClicked() ) );
   grid->addMultiCellWidget( mPop.leaveOnServerCheck, 6, 6, 0, 1 );
   TQHBox *afterDaysBox = new TQHBox( page1 );
   afterDaysBox->setSpacing( KDialog::spacingHint() );
   mPop.leaveOnServerDaysCheck =
     new TQCheckBox( i18n("Leave messages on the server for"), afterDaysBox );
-  connect( mPop.leaveOnServerDaysCheck, TQT_SIGNAL( toggled(bool) ),
-           this, TQT_SLOT( slotEnableLeaveOnServerDays(bool)) );
+  connect( mPop.leaveOnServerDaysCheck, TQ_SIGNAL( toggled(bool) ),
+           this, TQ_SLOT( slotEnableLeaveOnServerDays(bool)) );
   mPop.leaveOnServerDaysSpin = new KIntNumInput( afterDaysBox );
   mPop.leaveOnServerDaysSpin->setRange( 1, 365, 1, false );
-  connect( mPop.leaveOnServerDaysSpin, TQT_SIGNAL(valueChanged(int)),
-           TQT_SLOT(slotLeaveOnServerDaysChanged(int)));
+  connect( mPop.leaveOnServerDaysSpin, TQ_SIGNAL(valueChanged(int)),
+           TQ_SLOT(slotLeaveOnServerDaysChanged(int)));
   mPop.leaveOnServerDaysSpin->setValue( 1 );
   afterDaysBox->setStretchFactor( mPop.leaveOnServerDaysSpin, 1 );
   grid->addMultiCellWidget( afterDaysBox, 7, 7, 0, 1 );
@@ -658,20 +658,20 @@ void AccountDialog::makePopAccountPage()
   leaveOnServerCountBox->setSpacing( KDialog::spacingHint() );
   mPop.leaveOnServerCountCheck =
     new TQCheckBox( i18n("Keep only the last"), leaveOnServerCountBox );
-  connect( mPop.leaveOnServerCountCheck, TQT_SIGNAL( toggled(bool) ),
-           this, TQT_SLOT( slotEnableLeaveOnServerCount(bool)) );
+  connect( mPop.leaveOnServerCountCheck, TQ_SIGNAL( toggled(bool) ),
+           this, TQ_SLOT( slotEnableLeaveOnServerCount(bool)) );
   mPop.leaveOnServerCountSpin = new KIntNumInput( leaveOnServerCountBox );
   mPop.leaveOnServerCountSpin->setRange( 1, 999999, 1, false );
-  connect( mPop.leaveOnServerCountSpin, TQT_SIGNAL(valueChanged(int)),
-           TQT_SLOT(slotLeaveOnServerCountChanged(int)));
+  connect( mPop.leaveOnServerCountSpin, TQ_SIGNAL(valueChanged(int)),
+           TQ_SLOT(slotLeaveOnServerCountChanged(int)));
   mPop.leaveOnServerCountSpin->setValue( 100 );
   grid->addMultiCellWidget( leaveOnServerCountBox, 8, 8, 0, 1 );
   TQHBox *leaveOnServerSizeBox = new TQHBox( page1 );
   leaveOnServerSizeBox->setSpacing( KDialog::spacingHint() );
   mPop.leaveOnServerSizeCheck =
     new TQCheckBox( i18n("Keep only the last"), leaveOnServerSizeBox );
-  connect( mPop.leaveOnServerSizeCheck, TQT_SIGNAL( toggled(bool) ),
-           this, TQT_SLOT( slotEnableLeaveOnServerSize(bool)) );
+  connect( mPop.leaveOnServerSizeCheck, TQ_SIGNAL( toggled(bool) ),
+           this, TQ_SLOT( slotEnableLeaveOnServerSize(bool)) );
   mPop.leaveOnServerSizeSpin = new KIntNumInput( leaveOnServerSizeBox );
   mPop.leaveOnServerSizeSpin->setRange( 1, 999999, 1, false );
   mPop.leaveOnServerSizeSpin->setSuffix( i18n(" MB") );
@@ -685,21 +685,21 @@ void AccountDialog::makePopAccountPage()
   mPop.resourceClearButton =
       new TQPushButton( i18n( "Clear" ), resourceHB );
   mPop.resourceClearButton->setEnabled( false );
-  connect( mPop.resourceCheck, TQT_SIGNAL( toggled(bool) ),
-           mPop.resourceClearButton, TQT_SLOT( setEnabled(bool) ) );
+  connect( mPop.resourceCheck, TQ_SIGNAL( toggled(bool) ),
+           mPop.resourceClearButton, TQ_SLOT( setEnabled(bool) ) );
   TQWhatsThis::add( mPop.resourceClearButton,
                    i18n( "Delete all allocations for the resource represented by this account." ) );
-  connect( mPop.resourceClearButton, TQT_SIGNAL( clicked() ),
-           this, TQT_SLOT( slotClearResourceAllocations() ) );
+  connect( mPop.resourceClearButton, TQ_SIGNAL( clicked() ),
+           this, TQ_SLOT( slotClearResourceAllocations() ) );
   mPop.resourceClearPastButton =
       new TQPushButton( i18n( "Clear Past" ), resourceHB );
   mPop.resourceClearPastButton->setEnabled( false );
-  connect( mPop.resourceCheck, TQT_SIGNAL( toggled(bool) ),
-           mPop.resourceClearPastButton, TQT_SLOT( setEnabled(bool) ) );
+  connect( mPop.resourceCheck, TQ_SIGNAL( toggled(bool) ),
+           mPop.resourceClearPastButton, TQ_SLOT( setEnabled(bool) ) );
   TQWhatsThis::add( mPop.resourceClearPastButton,
                    i18n( "Delete all outdated allocations for the resource represented by this account." ) );
-  connect( mPop.resourceClearPastButton, TQT_SIGNAL( clicked() ),
-           this, TQT_SLOT( slotClearPastResourceAllocations() ) );
+  connect( mPop.resourceClearPastButton, TQ_SIGNAL( clicked() ),
+           this, TQ_SLOT( slotClearPastResourceAllocations() ) );
   grid->addMultiCellWidget( resourceHB, 10, 10, 0, 2 );
 #endif
 
@@ -715,14 +715,14 @@ void AccountDialog::makePopAccountPage()
   mPop.filterOnServerSizeSpin->setEnabled( false );
   hbox->setStretchFactor( mPop.filterOnServerSizeSpin, 1 );
   mPop.filterOnServerSizeSpin->setRange( 1, 10000000, 100, false );
-  connect(mPop.filterOnServerSizeSpin, TQT_SIGNAL(valueChanged(int)),
-          TQT_SLOT(slotFilterOnServerSizeChanged(int)));
+  connect(mPop.filterOnServerSizeSpin, TQ_SIGNAL(valueChanged(int)),
+          TQ_SLOT(slotFilterOnServerSizeChanged(int)));
   mPop.filterOnServerSizeSpin->setValue( 50000 );
   grid->addMultiCellWidget( hbox, 11, 11, 0, 1 );
-  connect( mPop.filterOnServerCheck, TQT_SIGNAL(toggled(bool)),
-	   mPop.filterOnServerSizeSpin, TQT_SLOT(setEnabled(bool)) );
-  connect( mPop.filterOnServerCheck, TQT_SIGNAL( clicked() ),
-           this, TQT_SLOT( slotFilterOnServerClicked() ) );
+  connect( mPop.filterOnServerCheck, TQ_SIGNAL(toggled(bool)),
+	   mPop.filterOnServerSizeSpin, TQ_SLOT(setEnabled(bool)) );
+  connect( mPop.filterOnServerCheck, TQ_SIGNAL( clicked() ),
+           this, TQ_SLOT( slotFilterOnServerClicked() ) );
   TQString msg = i18n("If you select this option, POP Filters will be used to "
 		     "decide what to do with messages. You can then select "
 		     "to download, delete or keep them on the server." );
@@ -732,8 +732,8 @@ void AccountDialog::makePopAccountPage()
   mPop.intervalCheck =
     new TQCheckBox( i18n("Enable &interval mail checking"), page1 );
   grid->addMultiCellWidget( mPop.intervalCheck, 12, 12, 0, 1 );
-  connect( mPop.intervalCheck, TQT_SIGNAL(toggled(bool)),
-	   this, TQT_SLOT(slotEnablePopInterval(bool)) );
+  connect( mPop.intervalCheck, TQ_SIGNAL(toggled(bool)),
+	   this, TQ_SLOT(slotEnablePopInterval(bool)) );
   mPop.intervalLabel = new TQLabel( i18n("Chec&k interval:"), page1 );
   grid->addWidget( mPop.intervalLabel, 13, 0 );
   mPop.intervalSpin = new KIntNumInput( page1 );
@@ -770,15 +770,15 @@ void AccountDialog::makePopAccountPage()
   TQHBoxLayout *buttonLay = new TQHBoxLayout( vlay );
   mPop.checkCapabilities =
     new TQPushButton( i18n("Check &What the Server Supports"), page2 );
-  connect(mPop.checkCapabilities, TQT_SIGNAL(clicked()),
-    TQT_SLOT(slotCheckPopCapabilities()));
+  connect(mPop.checkCapabilities, TQ_SIGNAL(clicked()),
+    TQ_SLOT(slotCheckPopCapabilities()));
   buttonLay->addStretch();
   buttonLay->addWidget( mPop.checkCapabilities );
   buttonLay->addStretch();
 
   vlay->addSpacing( KDialog::spacingHint() );
 
-  mPop.encryptionGroup = new TQButtonGroup( 1, Qt::Horizontal,
+  mPop.encryptionGroup = new TQButtonGroup( 1, TQt::Horizontal,
     i18n("Encryption"), page2 );
   mPop.encryptionNone =
     new TQRadioButton( i18n("&None"), mPop.encryptionGroup );
@@ -788,11 +788,11 @@ void AccountDialog::makePopAccountPage()
   mPop.encryptionTLS =
     new TQRadioButton( i18n("Use &TLS for secure mail download"),
     mPop.encryptionGroup );
-  connect(mPop.encryptionGroup, TQT_SIGNAL(clicked(int)),
-    TQT_SLOT(slotPopEncryptionChanged(int)));
+  connect(mPop.encryptionGroup, TQ_SIGNAL(clicked(int)),
+    TQ_SLOT(slotPopEncryptionChanged(int)));
   vlay->addWidget( mPop.encryptionGroup );
 
-  mPop.authGroup = new TQButtonGroup( 1, Qt::Horizontal,
+  mPop.authGroup = new TQButtonGroup( 1, TQt::Horizontal,
     i18n("Authentication Method"), page2 );
   mPop.authUser = new TQRadioButton( i18n("Clear te&xt") , mPop.authGroup,
                                     "auth clear text" );
@@ -817,13 +817,13 @@ void AccountDialog::makePopAccountPage()
 
   mPop.usePipeliningCheck =
     new TQCheckBox( i18n("&Use pipelining for faster mail download"), page2 );
-  connect(mPop.usePipeliningCheck, TQT_SIGNAL(clicked()),
-    TQT_SLOT(slotPipeliningClicked()));
+  connect(mPop.usePipeliningCheck, TQ_SIGNAL(clicked()),
+    TQ_SLOT(slotPipeliningClicked()));
   vlay->addWidget( mPop.usePipeliningCheck );
 
   vlay->addStretch();
 
-  connect(kapp,TQT_SIGNAL(tdedisplayFontChanged()),TQT_SLOT(slotFontChanged()));
+  connect(kapp,TQ_SIGNAL(tdedisplayFontChanged()),TQ_SLOT(slotFontChanged()));
 }
 
 
@@ -891,7 +891,7 @@ void AccountDialog::makeImapAccountPage( bool connected )
   label = new TQLabel( i18n("&Port:"), page1 );
   grid->addWidget( label, row, 0 );
   mImap.portEdit = new KLineEdit( page1 );
-  mImap.portEdit->setValidator( new TQIntValidator(TQT_TQOBJECT(this)) );
+  mImap.portEdit->setValidator( new TQIntValidator(this) );
   label->setBuddy( mImap.portEdit );
   grid->addWidget( mImap.portEdit, row, 1 );
 
@@ -909,7 +909,7 @@ void AccountDialog::makeImapAccountPage( bool connected )
   button->setFixedSize( 22, 22 );
   button->setIconSet(
       TDEGlobal::iconLoader()->loadIconSet( "reload", TDEIcon::Small, 0 ) );
-  connect( button, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotReloadNamespaces()) );
+  connect( button, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotReloadNamespaces()) );
   TQWhatsThis::add( button,
       i18n("Reload the namespaces from the server. This overwrites any changes.") );
   grid->addWidget( box, row, 0 );
@@ -926,7 +926,7 @@ void AccountDialog::makeImapAccountPage( bool connected )
   mImap.editPNS->setAutoRaise( true );
   mImap.editPNS->setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
   mImap.editPNS->setFixedSize( 22, 22 );
-  connect( mImap.editPNS, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotEditPersonalNamespace()) );
+  connect( mImap.editPNS, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotEditPersonalNamespace()) );
 
   label = new TQLabel( i18n("Other Users"), listbox );
   TQWhatsThis::add( label, i18n( "These namespaces include the folders of other users." ) );
@@ -938,7 +938,7 @@ void AccountDialog::makeImapAccountPage( bool connected )
   mImap.editONS->setAutoRaise( true );
   mImap.editONS->setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
   mImap.editONS->setFixedSize( 22, 22 );
-  connect( mImap.editONS, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotEditOtherUsersNamespace()) );
+  connect( mImap.editONS, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotEditOtherUsersNamespace()) );
 
   label = new TQLabel( i18n("Shared"), listbox );
   TQWhatsThis::add( label, i18n( "These namespaces include the shared folders." ) );
@@ -950,7 +950,7 @@ void AccountDialog::makeImapAccountPage( bool connected )
   mImap.editSNS->setAutoRaise( true );
   mImap.editSNS->setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
   mImap.editSNS->setFixedSize( 22, 22 );
-  connect( mImap.editSNS, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotEditSharedNamespace()) );
+  connect( mImap.editSNS, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotEditSharedNamespace()) );
 
   label->setBuddy( listbox );
   grid->addWidget( listbox, row, 1 );
@@ -1021,21 +1021,21 @@ void AccountDialog::makeImapAccountPage( bool connected )
   mImap.resourceClearButton =
       new TQPushButton( i18n( "Clear" ), resourceHB );
   mImap.resourceClearButton->setEnabled( false );
-  connect( mImap.resourceCheck, TQT_SIGNAL( toggled(bool) ),
-           mImap.resourceClearButton, TQT_SLOT( setEnabled(bool) ) );
+  connect( mImap.resourceCheck, TQ_SIGNAL( toggled(bool) ),
+           mImap.resourceClearButton, TQ_SLOT( setEnabled(bool) ) );
   TQWhatsThis::add( mImap.resourceClearButton,
                    i18n( "Delete all allocations for the resource represented by this account." ) );
-  connect( mImap.resourceClearButton, TQT_SIGNAL( clicked() ),
-           this, TQT_SLOT( slotClearResourceAllocations() ) );
+  connect( mImap.resourceClearButton, TQ_SIGNAL( clicked() ),
+           this, TQ_SLOT( slotClearResourceAllocations() ) );
   mImap.resourceClearPastButton =
       new TQPushButton( i18n( "Clear Past" ), resourceHB );
   mImap.resourceClearPastButton->setEnabled( false );
-  connect( mImap.resourceCheck, TQT_SIGNAL( toggled(bool) ),
-           mImap.resourceClearPastButton, TQT_SLOT( setEnabled(bool) ) );
+  connect( mImap.resourceCheck, TQ_SIGNAL( toggled(bool) ),
+           mImap.resourceClearPastButton, TQ_SLOT( setEnabled(bool) ) );
   TQWhatsThis::add( mImap.resourceClearPastButton,
                    i18n( "Delete all outdated allocations for the resource represented by this account." ) );
-  connect( mImap.resourceClearPastButton, TQT_SIGNAL( clicked() ),
-           this, TQT_SLOT( slotClearPastResourceAllocations() ) );
+  connect( mImap.resourceClearPastButton, TQ_SIGNAL( clicked() ),
+           this, TQ_SLOT( slotClearPastResourceAllocations() ) );
   grid->addMultiCellWidget( resourceHB, row, row, 0, 2 );
 #endif
 
@@ -1048,8 +1048,8 @@ void AccountDialog::makeImapAccountPage( bool connected )
   mImap.intervalCheck =
     new TQCheckBox( i18n("Enable &interval mail checking"), page1 );
   grid->addMultiCellWidget( mImap.intervalCheck, row, row, 0, 2 );
-  connect( mImap.intervalCheck, TQT_SIGNAL(toggled(bool)),
-	   this, TQT_SLOT(slotEnableImapInterval(bool)) );
+  connect( mImap.intervalCheck, TQ_SIGNAL(toggled(bool)),
+	   this, TQ_SLOT(slotEnableImapInterval(bool)) );
   ++row;
   mImap.intervalLabel = new TQLabel( i18n("Check inter&val:"), page1 );
   grid->addWidget( mImap.intervalLabel, row, 0 );
@@ -1085,15 +1085,15 @@ void AccountDialog::makeImapAccountPage( bool connected )
   TQHBoxLayout *buttonLay = new TQHBoxLayout( vlay );
   mImap.checkCapabilities =
     new TQPushButton( i18n("Check &What the Server Supports"), page2 );
-  connect(mImap.checkCapabilities, TQT_SIGNAL(clicked()),
-    TQT_SLOT(slotCheckImapCapabilities()));
+  connect(mImap.checkCapabilities, TQ_SIGNAL(clicked()),
+    TQ_SLOT(slotCheckImapCapabilities()));
   buttonLay->addStretch();
   buttonLay->addWidget( mImap.checkCapabilities );
   buttonLay->addStretch();
 
   vlay->addSpacing( KDialog::spacingHint() );
 
-  mImap.encryptionGroup = new TQButtonGroup( 1, Qt::Horizontal,
+  mImap.encryptionGroup = new TQButtonGroup( 1, TQt::Horizontal,
     i18n("Encryption"), page2 );
   mImap.encryptionNone =
     new TQRadioButton( i18n("&None"), mImap.encryptionGroup );
@@ -1103,11 +1103,11 @@ void AccountDialog::makeImapAccountPage( bool connected )
   mImap.encryptionTLS =
     new TQRadioButton( i18n("Use &TLS for secure mail download"),
     mImap.encryptionGroup );
-  connect(mImap.encryptionGroup, TQT_SIGNAL(clicked(int)),
-    TQT_SLOT(slotImapEncryptionChanged(int)));
+  connect(mImap.encryptionGroup, TQ_SIGNAL(clicked(int)),
+    TQ_SLOT(slotImapEncryptionChanged(int)));
   vlay->addWidget( mImap.encryptionGroup );
 
-  mImap.authGroup = new TQButtonGroup( 1, Qt::Horizontal,
+  mImap.authGroup = new TQButtonGroup( 1, TQt::Horizontal,
     i18n("Authentication Method"), page2 );
   mImap.authUser = new TQRadioButton( i18n("Clear te&xt"), mImap.authGroup );
   mImap.authLogin = new TQRadioButton( i18n("Please translate this "
@@ -1130,7 +1130,7 @@ void AccountDialog::makeImapAccountPage( bool connected )
   mSieveConfigEditor->layout()->setMargin( KDialog::marginHint() );
   tabWidget->addTab( mSieveConfigEditor, i18n("&Filtering") );
 
-  connect(kapp,TQT_SIGNAL(tdedisplayFontChanged()),TQT_SLOT(slotFontChanged()));
+  connect(kapp,TQ_SIGNAL(tdedisplayFontChanged()),TQ_SLOT(slotFontChanged()));
 }
 
 
@@ -1542,9 +1542,9 @@ void AccountDialog::slotCheckPopCapabilities()
   delete mServerTest;
   mServerTest = new KMServerTest(POP_PROTOCOL, mPop.hostEdit->text(),
     mPop.portEdit->text().toInt());
-  connect( mServerTest, TQT_SIGNAL( capabilities( const TQStringList &,
+  connect( mServerTest, TQ_SIGNAL( capabilities( const TQStringList &,
                                               const TQStringList & ) ),
-           this, TQT_SLOT( slotPopCapabilities( const TQStringList &,
+           this, TQ_SLOT( slotPopCapabilities( const TQStringList &,
                                             const TQStringList & ) ) );
   mPop.checkCapabilities->setEnabled(false);
 }
@@ -1561,9 +1561,9 @@ void AccountDialog::slotCheckImapCapabilities()
   delete mServerTest;
   mServerTest = new KMServerTest(IMAP_PROTOCOL, mImap.hostEdit->text(),
     mImap.portEdit->text().toInt());
-  connect( mServerTest, TQT_SIGNAL( capabilities( const TQStringList &,
+  connect( mServerTest, TQ_SIGNAL( capabilities( const TQStringList &,
                                               const TQStringList & ) ),
-           this, TQT_SLOT( slotImapCapabilities( const TQStringList &,
+           this, TQ_SLOT( slotImapCapabilities( const TQStringList &,
                                              const TQStringList & ) ) );
   mImap.checkCapabilities->setEnabled(false);
 }
@@ -2120,10 +2120,10 @@ void AccountDialog::slotReloadNamespaces()
     mImap.otherUsersNS->setText( TQString() );
     mImap.sharedNS->setText( TQString() );
     ImapAccountBase* ai = static_cast<ImapAccountBase*>( mAccount );
-    connect( ai, TQT_SIGNAL( namespacesFetched( const ImapAccountBase::nsDelimMap& ) ),
-        this, TQT_SLOT( slotSetupNamespaces( const ImapAccountBase::nsDelimMap& ) ) );
-    connect( ai, TQT_SIGNAL( connectionResult(int, const TQString&) ),
-          this, TQT_SLOT( slotConnectionResult(int, const TQString&) ) );
+    connect( ai, TQ_SIGNAL( namespacesFetched( const ImapAccountBase::nsDelimMap& ) ),
+        this, TQ_SLOT( slotSetupNamespaces( const ImapAccountBase::nsDelimMap& ) ) );
+    connect( ai, TQ_SIGNAL( connectionResult(int, const TQString&) ),
+          this, TQ_SLOT( slotConnectionResult(int, const TQString&) ) );
     ai->getNamespaces();
   }
 }
@@ -2132,17 +2132,17 @@ void AccountDialog::slotConnectionResult( int errorCode, const TQString& )
 {
   if ( errorCode > 0 ) {
     ImapAccountBase* ai = static_cast<ImapAccountBase*>( mAccount );
-    disconnect( ai, TQT_SIGNAL( namespacesFetched( const ImapAccountBase::nsDelimMap& ) ),
-        this, TQT_SLOT( slotSetupNamespaces( const ImapAccountBase::nsDelimMap& ) ) );
-    disconnect( ai, TQT_SIGNAL( connectionResult(int, const TQString&) ),
-          this, TQT_SLOT( slotConnectionResult(int, const TQString&) ) );
+    disconnect( ai, TQ_SIGNAL( namespacesFetched( const ImapAccountBase::nsDelimMap& ) ),
+        this, TQ_SLOT( slotSetupNamespaces( const ImapAccountBase::nsDelimMap& ) ) );
+    disconnect( ai, TQ_SIGNAL( connectionResult(int, const TQString&) ),
+          this, TQ_SLOT( slotConnectionResult(int, const TQString&) ) );
     mImap.personalNS->setText( TQString() );
   }
 }
 
 void AccountDialog::slotSetupNamespaces( const ImapAccountBase::nsDelimMap& map )
 {
-  disconnect( this, TQT_SLOT( slotSetupNamespaces( const ImapAccountBase::nsDelimMap& ) ) );
+  disconnect( this, TQ_SLOT( slotSetupNamespaces( const ImapAccountBase::nsDelimMap& ) ) );
   mImap.personalNS->setText( TQString() );
   mImap.otherUsersNS->setText( TQString() );
   mImap.sharedNS->setText( TQString() );
@@ -2297,7 +2297,7 @@ NamespaceEditDialog::NamespaceEditDialog( TQWidget *parent,
   TQGrid* grid = new TQGrid( 2, page );
 
   mBg = new TQButtonGroup( 0 );
-  connect( mBg, TQT_SIGNAL( clicked(int) ), this, TQT_SLOT( slotRemoveEntry(int) ) );
+  connect( mBg, TQ_SIGNAL( clicked(int) ), this, TQ_SLOT( slotRemoveEntry(int) ) );
   mDelimMap = mNamespaceMap->find( mType ).data();
   ImapAccountBase::namespaceDelim::Iterator it;
   for ( it = mDelimMap.begin(); it != mDelimMap.end(); ++it ) {
