@@ -282,8 +282,8 @@ void AccountWizard::setupServerInformationPage()
   mIncomingLocation = new KLineEdit( mIncomingLocationWdg );
   mChooseLocation = new TQPushButton( i18n( "Choose..." ), mIncomingLocationWdg );
 
-  connect( mChooseLocation, TQT_SIGNAL( clicked() ),
-           this, TQT_SLOT( chooseLocation() ) );
+  connect( mChooseLocation, TQ_SIGNAL( clicked() ),
+           this, TQ_SLOT( chooseLocation() ) );
 
   layout->addWidget( mIncomingLabel, 0, 0, AlignTop );
   layout->addWidget( mIncomingLocationWdg, 0, 1 );
@@ -303,8 +303,8 @@ void AccountWizard::setupServerInformationPage()
                                   mServerInformationPage );
   layout->addWidget( mLocalDelivery, 3, 0 );
 
-  connect( mLocalDelivery, TQT_SIGNAL( toggled( bool ) ),
-           mOutgoingServer, TQT_SLOT( setDisabled( bool ) ) );
+  connect( mLocalDelivery, TQ_SIGNAL( toggled( bool ) ),
+           mOutgoingServer, TQ_SLOT( setDisabled( bool ) ) );
 
   addPage( mServerInformationPage, i18n( "Server Information" ) );
 }
@@ -361,7 +361,7 @@ void AccountWizard::accept()
 
   manager->commit();
 
-  TQTimer::singleShot( 0, this, TQT_SLOT( createTransport() ) );
+  TQTimer::singleShot( 0, this, TQ_SLOT( createTransport() ) );
 }
 
 void AccountWizard::createTransport()
@@ -386,7 +386,7 @@ void AccountWizard::createTransport()
     mTransportInfo->auth = false;
     mTransportInfo->setStorePasswd( false );
 
-    TQTimer::singleShot( 0, this, TQT_SLOT( transportCreated() ) );
+    TQTimer::singleShot( 0, this, TQ_SLOT( transportCreated() ) );
   } else { // delivery via SMTP
     mTransportInfo->type = "smtp";
     mTransportInfo->name = accountName();
@@ -425,7 +425,7 @@ void AccountWizard::transportCreated()
   mTransportInfoList.setAutoDelete( true );
   mTransportInfoList.clear();
 
-  TQTimer::singleShot( 0, this, TQT_SLOT( createAccount() ) );
+  TQTimer::singleShot( 0, this, TQ_SLOT( createAccount() ) );
 }
 
 void AccountWizard::createAccount()
@@ -485,7 +485,7 @@ void AccountWizard::createAccount()
   else if ( mTypeBox->type() == AccountTypeBox::IMAP || mTypeBox->type() == AccountTypeBox::dIMAP )
     checkImapCapabilities( mIncomingServer->text(), port );
   else
-    TQTimer::singleShot( 0, this, TQT_SLOT( accountCreated() ) );
+    TQTimer::singleShot( 0, this, TQ_SLOT( accountCreated() ) );
 }
 
 void AccountWizard::accountCreated()
@@ -513,8 +513,8 @@ void AccountWizard::checkPopCapabilities( const TQString &server, int port )
   delete mServerTest;
   mServerTest = new KMServerTest( POP_PROTOCOL, server, port );
 
-  connect( mServerTest, TQT_SIGNAL( capabilities( const TQStringList&, const TQStringList& ) ),
-           this, TQT_SLOT( popCapabilities( const TQStringList&, const TQStringList& ) ) );
+  connect( mServerTest, TQ_SIGNAL( capabilities( const TQStringList&, const TQStringList& ) ),
+           this, TQ_SLOT( popCapabilities( const TQStringList&, const TQStringList& ) ) );
 
   mAuthInfoLabel = createInfoLabel( i18n( "Check for supported security capabilities of %1..." ).arg( server ) );
 }
@@ -524,8 +524,8 @@ void AccountWizard::checkImapCapabilities( const TQString &server, int port )
   delete mServerTest;
   mServerTest = new KMServerTest( IMAP_PROTOCOL, server, port );
 
-  connect( mServerTest, TQT_SIGNAL( capabilities( const TQStringList&, const TQStringList& ) ),
-           this, TQT_SLOT( imapCapabilities( const TQStringList&, const TQStringList& ) ) );
+  connect( mServerTest, TQ_SIGNAL( capabilities( const TQStringList&, const TQStringList& ) ),
+           this, TQ_SLOT( imapCapabilities( const TQStringList&, const TQStringList& ) ) );
 
   mAuthInfoLabel = createInfoLabel( i18n( "Check for supported security capabilities of %1..." ).arg( server ) );
 }
@@ -535,9 +535,9 @@ void AccountWizard::checkSmtpCapabilities( const TQString &server, int port )
   delete mServerTest;
   mServerTest = new KMServerTest( SMTP_PROTOCOL, server, port );
 
-  connect( mServerTest, TQT_SIGNAL( capabilities( const TQStringList&, const TQStringList&,
+  connect( mServerTest, TQ_SIGNAL( capabilities( const TQStringList&, const TQStringList&,
                                               const TQString&, const TQString&, const TQString& ) ),
-           this, TQT_SLOT( smtpCapabilities( const TQStringList&, const TQStringList&,
+           this, TQ_SLOT( smtpCapabilities( const TQStringList&, const TQStringList&,
                                          const TQString&, const TQString&, const TQString& ) ) );
 
   mAuthInfoLabel = createInfoLabel( i18n( "Check for supported security capabilities of %1..." ).arg( server ) );
