@@ -29,7 +29,7 @@ class Composer;
 
 class AttachmentListView : public TDEListView
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   AttachmentListView( KMail::Composer * composer = 0, TQWidget* parent = 0,
