@@ -17,7 +17,7 @@
 #include <tdelistview.h>
 #include <tdecmodule.h>
 #include <tdelocale.h>
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 class TQPushButton;
 class TQLabel;
@@ -76,7 +76,7 @@ namespace Kleo {
 
 class NewIdentityDialog : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -122,7 +122,7 @@ typedef TQValueList<LanguageItem> LanguageItemList;
 
 class NewLanguageDialog : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
@@ -137,7 +137,7 @@ class NewLanguageDialog : public KDialogBase
 
 class LanguageComboBox : public TQComboBox
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
@@ -154,7 +154,7 @@ class LanguageComboBox : public TQComboBox
 //
 
 class ProfileDialog : public KDialogBase {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   ProfileDialog( TQWidget * parent=0, const char * name=0, bool modal=false );
@@ -176,7 +176,7 @@ private:
 
 #include <kdialog.h>
 class ConfigModule : public TDECModule {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   ConfigModule( TQWidget * parent=0, const char * name=0 )
@@ -204,7 +204,7 @@ signals:
 
 // Individual tab of a ConfigModuleWithTabs
 class ConfigModuleTab : public TQWidget {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
    ConfigModuleTab( TQWidget *parent=0, const char* name=0 )
@@ -239,7 +239,7 @@ private:
  * It simply forwards load and save operations to all tabs.
  */
 class ConfigModuleWithTabs : public ConfigModule {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   ConfigModuleWithTabs( TQWidget * parent=0, const char * name=0 );
@@ -267,7 +267,7 @@ private:
 //
 
 class KDE_EXPORT IdentityPage : public ConfigModule {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   IdentityPage( TQWidget * parent=0, const char * name=0 );
@@ -318,7 +318,7 @@ private: // data members
 
 // subclasses: one class per tab:
 class AccountsPageSendingTab : public ConfigModuleTab {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   AccountsPageSendingTab( TQWidget * parent=0, const char * name=0 );
@@ -356,7 +356,7 @@ private:
 
 
 class AccountsPageReceivingTab : public ConfigModuleTab {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   AccountsPageReceivingTab( TQWidget * parent=0, const char * name=0 );
@@ -401,7 +401,7 @@ private:
 };
 
 class KDE_EXPORT AccountsPage : public ConfigModuleWithTabs {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   AccountsPage( TQWidget * parent=0, const char * name=0 );
@@ -429,7 +429,7 @@ private:
 //
 
 class AppearancePageFontsTab : public ConfigModuleTab {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   AppearancePageFontsTab( TQWidget * parent=0, const char * name=0 );
@@ -457,7 +457,7 @@ private:
 };
 
 class AppearancePageColorsTab : public ConfigModuleTab {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   AppearancePageColorsTab( TQWidget * parent=0, const char * name=0 );
@@ -479,7 +479,7 @@ private:
 };
 
 class AppearancePageLayoutTab : public ConfigModuleTab {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   AppearancePageLayoutTab( TQWidget * parent=0, const char * name=0 );
@@ -502,7 +502,7 @@ private: // data
 };
 
 class AppearancePageHeadersTab : public ConfigModuleTab {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   AppearancePageHeadersTab( TQWidget * parent=0, const char * name=0 );
@@ -529,7 +529,7 @@ private: // data
 };
 
 class AppearancePageReaderTab : public ConfigModuleTab {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   AppearancePageReaderTab( TQWidget * parent=0, const char * name=0 );
@@ -561,7 +561,7 @@ private: // data
 
 
 class AppearancePageSystemTrayTab : public ConfigModuleTab {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   AppearancePageSystemTrayTab( TQWidget * parent=0, const char * name=0 );
@@ -580,7 +580,7 @@ private: // data
 };
 
 class KDE_EXPORT AppearancePage : public ConfigModuleWithTabs {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   AppearancePage( TQWidget * parent=0, const char * name=0 );
@@ -611,7 +611,7 @@ private:
 //
 
 class ComposerPageGeneralTab : public ConfigModuleTab {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   ComposerPageGeneralTab( TQWidget * parent=0, const char * name=0 );
@@ -645,7 +645,7 @@ private:
 };
 
 class ComposerPagePhrasesTab : public ConfigModuleTab {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   ComposerPagePhrasesTab( TQWidget * parent=0, const char * name=0 );
@@ -677,7 +677,7 @@ private:
 };
 
 class ComposerPageTemplatesTab : public ConfigModuleTab {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   ComposerPageTemplatesTab( TQWidget * parent=0, const char * name=0 );
@@ -695,7 +695,7 @@ private:
 };
 
 class ComposerPageCustomTemplatesTab : public ConfigModuleTab {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   ComposerPageCustomTemplatesTab( TQWidget * parent=0, const char * name=0 );
@@ -713,7 +713,7 @@ private:
 };
 
 class ComposerPageSubjectTab : public ConfigModuleTab {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   ComposerPageSubjectTab( TQWidget * parent=0, const char * name=0 );
@@ -732,7 +732,7 @@ private:
 };
 
 class ComposerPageCharsetTab : public ConfigModuleTab {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   ComposerPageCharsetTab( TQWidget * parent=0, const char * name=0 );
@@ -754,7 +754,7 @@ private:
 };
 
 class ComposerPageHeadersTab : public ConfigModuleTab {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   ComposerPageHeadersTab( TQWidget * parent=0, const char * name=0 );
@@ -787,7 +787,7 @@ private:
 };
 
 class ComposerPageAttachmentsTab : public ConfigModuleTab {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   ComposerPageAttachmentsTab( TQWidget * parent=0, const char * name=0 );
@@ -809,7 +809,7 @@ private:
 };
 
 class KDE_EXPORT ComposerPage : public ConfigModuleWithTabs {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   ComposerPage( TQWidget * parent=0, const char * name=0 );
@@ -844,7 +844,7 @@ private:
 //
 
 class SecurityPageGeneralTab : public ConfigModuleTab {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   SecurityPageGeneralTab( TQWidget * parent=0, const char * name=0 );
@@ -870,7 +870,7 @@ private:
 
 
 class SecurityPageComposerCryptoTab : public ConfigModuleTab {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   SecurityPageComposerCryptoTab( TQWidget * parent=0, const char * name=0 );
@@ -890,7 +890,7 @@ private:
 };
 
 class SecurityPageWarningTab : public ConfigModuleTab {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   SecurityPageWarningTab( TQWidget * parent=0, const char * name=0 );
@@ -913,7 +913,7 @@ private:
 };
 
 class SecurityPageSMimeTab : public ConfigModuleTab, public DCOPObject {
-  Q_OBJECT
+  TQ_OBJECT
   
   K_DCOP
 public:
@@ -941,7 +941,7 @@ private:
 
 class SecurityPageCryptPlugTab : public ConfigModuleTab
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   SecurityPageCryptPlugTab( TQWidget * parent = 0, const char* name = 0 );
@@ -960,7 +960,7 @@ private:
 };
 
 class KDE_EXPORT SecurityPage : public ConfigModuleWithTabs {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   SecurityPage( TQWidget * parent=0, const char * name=0 );
@@ -992,7 +992,7 @@ private:
 //
 
 class MiscPageFolderTab : public ConfigModuleTab {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   MiscPageFolderTab( TQWidget * parent=0, const char * name=0 );
@@ -1023,7 +1023,7 @@ private:
 };
 
 class MiscPageGroupwareTab : public ConfigModuleTab  {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   MiscPageGroupwareTab( TQWidget * parent=0, const char * name=0 );
@@ -1065,7 +1065,7 @@ private:
 };
 
 class KDE_EXPORT MiscPage : public ConfigModuleWithTabs {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   MiscPage( TQWidget * parent=0, const char * name=0 );
@@ -1086,7 +1086,7 @@ private:
 //
 
 class ListView : public TDEListView {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   ListView( TQWidget *parent=0, const char *name=0, int visibleItem=10 );
