@@ -42,7 +42,7 @@ namespace KMail {
       @author Marc Mutz <mutz@kde.org>
   **/
   class IdentityDrag : public TQDragObject {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     IdentityDrag( const KPIM::Identity & ident,
