@@ -48,7 +48,7 @@ typedef TQMap<partNode*, KMMessage*> PartNodeMessageMap;
 
 class KDE_EXPORT KMCommand : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
     friend class LaterDeleterWithCommandCompletion;
 
@@ -162,7 +162,7 @@ private:
 
 class KDE_EXPORT KMMailtoComposeCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -177,7 +177,7 @@ private:
 
 class KDE_EXPORT KMMailtoReplyCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -193,7 +193,7 @@ private:
 
 class KDE_EXPORT KMMailtoForwardCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -208,7 +208,7 @@ private:
 
 class KDE_EXPORT KMMailtoAddAddrBookCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -222,7 +222,7 @@ private:
 
 class KDE_EXPORT KMAddBookmarksCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -237,7 +237,7 @@ private:
 
 class KDE_EXPORT KMMailtoOpenAddrBookCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -251,7 +251,7 @@ private:
 
 class KDE_EXPORT KMUrlCopyCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -266,7 +266,7 @@ private:
 
 class KDE_EXPORT KMUrlOpenCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -281,7 +281,7 @@ private:
 
 class KDE_EXPORT KMUrlSaveCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -298,7 +298,7 @@ private:
 
 class KDE_EXPORT KMEditMsgCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -310,7 +310,7 @@ private:
 
 class KDE_EXPORT KMUseTemplateCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -322,7 +322,7 @@ private:
 
 class KDE_EXPORT KMShowMsgSrcCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -337,7 +337,7 @@ private:
 
 class KDE_EXPORT KMSaveMsgCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -369,7 +369,7 @@ private:
 
 class KDE_EXPORT KMOpenMsgCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -393,7 +393,7 @@ private:
 
 class KDE_EXPORT KMSaveAttachmentsCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   /** Use this to save all attachments of the given message.
@@ -432,7 +432,7 @@ private:
 
 class KDE_EXPORT KMReplyToCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -448,7 +448,7 @@ private:
 
 class KDE_EXPORT KMNoQuoteReplyToCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -460,7 +460,7 @@ private:
 
 class KMReplyListCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -476,7 +476,7 @@ private:
 
 class KDE_EXPORT KMReplyToAllCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -492,7 +492,7 @@ private:
 
 class KDE_EXPORT KMReplyAuthorCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -508,7 +508,7 @@ private:
 
 class KDE_EXPORT KMForwardInlineCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -526,7 +526,7 @@ private:
 
 class KDE_EXPORT KMForwardAttachedCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -544,7 +544,7 @@ private:
 
 class KDE_EXPORT KMForwardDigestCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -562,7 +562,7 @@ private:
 
 class KDE_EXPORT KMRedirectCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -574,7 +574,7 @@ private:
 
 class KDE_EXPORT KMCustomReplyToCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -592,7 +592,7 @@ private:
 
 class KDE_EXPORT KMCustomReplyAllToCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -610,7 +610,7 @@ private:
 
 class KDE_EXPORT KMCustomForwardCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -628,7 +628,7 @@ private:
 
 class KDE_EXPORT KMPrintCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -656,7 +656,7 @@ private:
 
 class KDE_EXPORT KMSeStatusCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -675,7 +675,7 @@ private:
 
 class KDE_EXPORT KMFilterCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -691,7 +691,7 @@ private:
 
 class KDE_EXPORT KMFilterActionCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -708,7 +708,7 @@ private:
 
 class KDE_EXPORT KMMetaFilterActionCommand : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -726,7 +726,7 @@ private:
 
 class KDE_EXPORT FolderShortcutCommand : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -749,7 +749,7 @@ private:
 
 class KDE_EXPORT KMMailingListFilterCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -769,7 +769,7 @@ private:
 
 class KDE_EXPORT KMMenuCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -782,7 +782,7 @@ public:
 
 class KDE_EXPORT KMCopyCommand : public KMMenuCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -808,7 +808,7 @@ namespace KPIM {
 }
 class KDE_EXPORT KMMoveCommand : public KMMenuCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -844,7 +844,7 @@ private:
 
 class KDE_EXPORT KMDeleteMsgCommand : public KMMoveCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -859,7 +859,7 @@ private:
 
 class KDE_EXPORT KMUrlClickedCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -878,7 +878,7 @@ private:
 
 class KDE_EXPORT KMLoadPartsCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -904,7 +904,7 @@ private:
 
 class KDE_EXPORT KMResendMessageCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -916,7 +916,7 @@ private:
 
 class KDE_EXPORT KMMailingListCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KMMailingListCommand( TQWidget *parent, KMFolder *folder );
@@ -932,7 +932,7 @@ protected:
 
 class KDE_EXPORT KMMailingListPostCommand : public KMMailingListCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KMMailingListPostCommand( TQWidget *parent, KMFolder *folder );
@@ -942,7 +942,7 @@ protected:
 
 class KDE_EXPORT KMMailingListSubscribeCommand : public KMMailingListCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KMMailingListSubscribeCommand( TQWidget *parent, KMFolder *folder );
@@ -952,7 +952,7 @@ protected:
 
 class KDE_EXPORT KMMailingListUnsubscribeCommand : public KMMailingListCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KMMailingListUnsubscribeCommand( TQWidget *parent, KMFolder *folder );
@@ -962,7 +962,7 @@ protected:
 
 class KDE_EXPORT KMMailingListArchivesCommand : public KMMailingListCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KMMailingListArchivesCommand( TQWidget *parent, KMFolder *folder );
@@ -972,7 +972,7 @@ protected:
 
 class KDE_EXPORT KMMailingListHelpCommand : public KMMailingListCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KMMailingListHelpCommand( TQWidget *parent, KMFolder *folder );
@@ -982,7 +982,7 @@ protected:
 
 class KDE_EXPORT KMIMChatCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -1003,7 +1003,7 @@ private:
 
 class KDE_EXPORT KMHandleAttachmentCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -1090,7 +1090,7 @@ private:
 /** Base class for commands modifying attachements of existing messages. */
 class KDE_EXPORT AttachmentModifyCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     AttachmentModifyCommand( partNode *node, KMMessage *msg, TQWidget *parent );
@@ -1118,7 +1118,7 @@ class KDE_EXPORT AttachmentModifyCommand : public KMCommand
 
 class KDE_EXPORT KMDeleteAttachmentCommand : public AttachmentModifyCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     KMDeleteAttachmentCommand( partNode *node, KMMessage *msg, TQWidget *parent );
@@ -1132,7 +1132,7 @@ class KDE_EXPORT KMDeleteAttachmentCommand : public AttachmentModifyCommand
 
 class KDE_EXPORT KMEditAttachmentCommand : public AttachmentModifyCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     KMEditAttachmentCommand( partNode *node, KMMessage *msg, TQWidget *parent );
@@ -1151,7 +1151,7 @@ class KDE_EXPORT KMEditAttachmentCommand : public AttachmentModifyCommand
 
 class KDE_EXPORT CreateTodoCommand : public KMCommand
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     CreateTodoCommand( TQWidget *parent, KMMessage *msg );
