@@ -1,4 +1,4 @@
-/* -*- mode: C++; c-file-style: "gnu" -*-
+/*
  * KMComposeWin Header File
  * Author: Markus Wuebben <markus.wuebben@kde.org>
  */
@@ -98,7 +98,7 @@ namespace GpgME {
 //-----------------------------------------------------------------------------
 class KMComposeWin : public KMail::Composer, public MailComposerIface
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   friend class ::KMEdit;
   friend class ::MessageComposer;
