@@ -67,7 +67,7 @@ typedef TQValueList<TQ_UINT32> SerNumList;
 
 class KMFolder: public KMFolderNode
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   friend class ::KMFolderJob;
 public:
