@@ -77,7 +77,7 @@ private:
 
 class KMFolderImap : public KMFolderMbox
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   friend class ::KMail::ImapJob;
 public:
