@@ -251,7 +251,7 @@ KMTransportSelDlg::KMTransportSelDlg( TQWidget *parent, const char *name,
   TQVBoxLayout *topLayout = new TQVBoxLayout( page, 0, spacingHint() );
 
   TQButtonGroup *group = new TQButtonGroup( i18n("Transport"), page );
-  connect(group, TQT_SIGNAL(clicked(int)), TQT_SLOT(buttonClicked(int)) );
+  connect(group, TQ_SIGNAL(clicked(int)), TQ_SLOT(buttonClicked(int)) );
 
   topLayout->addWidget( group, 10 );
   TQVBoxLayout *vlay = new TQVBoxLayout( group, spacingHint()*2, spacingHint() );
@@ -339,11 +339,11 @@ void KMTransportDialog::makeSendmailPage()
   grid->addWidget( mSendmail.locationEdit, 1, 1 );
   mSendmail.chooseButton =
     new TQPushButton( i18n("Choos&e..."), page );
-  connect( mSendmail.chooseButton, TQT_SIGNAL(clicked()),
-           this, TQT_SLOT(slotSendmailChooser()) );
+  connect( mSendmail.chooseButton, TQ_SIGNAL(clicked()),
+           this, TQ_SLOT(slotSendmailChooser()) );
 
-  connect( mSendmail.locationEdit, TQT_SIGNAL(textChanged ( const TQString & )),
-           this, TQT_SLOT(slotSendmailEditPath(const TQString &)) );
+  connect( mSendmail.locationEdit, TQ_SIGNAL(textChanged ( const TQString & )),
+           this, TQ_SLOT(slotSendmailEditPath(const TQString &)) );
 
   mSendmail.chooseButton->setAutoDefault( false );
   grid->addWidget( mSendmail.chooseButton, 1, 2 );
@@ -401,7 +401,7 @@ void KMTransportDialog::makeSmtpPage()
   label = new TQLabel( i18n("&Port:"), page1 );
   grid->addWidget( label, 4, 0 );
   mSmtp.portEdit = new KLineEdit( page1 );
-  mSmtp.portEdit->setValidator( new TQIntValidator(TQT_TQOBJECT(this)) );
+  mSmtp.portEdit->setValidator( new TQIntValidator(this) );
   TQWhatsThis::add(mSmtp.portEdit,
                   i18n("The port number that the SMTP server "
                        "is listening on. The default port is 25."));
@@ -430,8 +430,8 @@ void KMTransportDialog::makeSmtpPage()
                        "requires authentication before accepting "
                        "mail. This is known as "
                        "'Authenticated SMTP' or simply ASMTP."));
-  connect(mSmtp.authCheck, TQT_SIGNAL(clicked()),
-          TQT_SLOT(slotRequiresAuthClicked()));
+  connect(mSmtp.authCheck, TQ_SIGNAL(clicked()),
+          TQ_SLOT(slotRequiresAuthClicked()));
   grid->addMultiCellWidget( mSmtp.authCheck, 7, 7, 0, 1 );
 
   mSmtp.loginLabel = new TQLabel( i18n("&Login:"), page1 );
@@ -490,15 +490,15 @@ void KMTransportDialog::makeSmtpPage()
                        "identifying itself to the server."));
   mSmtp.localHostnameLabel->setBuddy( mSmtp.localHostnameEdit );
   grid->addWidget( mSmtp.localHostnameEdit, 13, 1 );
-  connect( mSmtp.specifyHostnameCheck, TQT_SIGNAL(toggled(bool)),
-           mSmtp.localHostnameEdit, TQT_SLOT(setEnabled(bool)));
-  connect( mSmtp.specifyHostnameCheck, TQT_SIGNAL(toggled(bool)),
-           mSmtp.localHostnameLabel, TQT_SLOT(setEnabled(bool)));
+  connect( mSmtp.specifyHostnameCheck, TQ_SIGNAL(toggled(bool)),
+           mSmtp.localHostnameEdit, TQ_SLOT(setEnabled(bool)));
+  connect( mSmtp.specifyHostnameCheck, TQ_SIGNAL(toggled(bool)),
+           mSmtp.localHostnameLabel, TQ_SLOT(setEnabled(bool)));
 
   TQWidget *page2 = new TQWidget( tabWidget );
   tabWidget->addTab( page2, i18n("S&ecurity") );
   TQVBoxLayout *vlay = new TQVBoxLayout( page2, spacingHint() );
-  mSmtp.encryptionGroup = new TQButtonGroup( 1, Qt::Horizontal,
+  mSmtp.encryptionGroup = new TQButtonGroup( 1, TQt::Horizontal,
     i18n("Encryption"), page2 );
   mSmtp.encryptionNone =
     new TQRadioButton( i18n("&None"), mSmtp.encryptionGroup );
@@ -506,11 +506,11 @@ void KMTransportDialog::makeSmtpPage()
     new TQRadioButton( i18n("&SSL"), mSmtp.encryptionGroup );
   mSmtp.encryptionTLS =
     new TQRadioButton( i18n("&TLS"), mSmtp.encryptionGroup );
-  connect(mSmtp.encryptionGroup, TQT_SIGNAL(clicked(int)),
-    TQT_SLOT(slotSmtpEncryptionChanged(int)));
+  connect(mSmtp.encryptionGroup, TQ_SIGNAL(clicked(int)),
+    TQ_SLOT(slotSmtpEncryptionChanged(int)));
   vlay->addWidget( mSmtp.encryptionGroup );
 
-  mSmtp.authGroup = new TQButtonGroup( 1, Qt::Horizontal,
+  mSmtp.authGroup = new TQButtonGroup( 1, TQt::Horizontal,
     i18n("Authentication Method"), page2 );
   mSmtp.authLogin = new TQRadioButton( i18n("Please translate this "
     "authentication method only if you have a good reason", "&LOGIN"),
@@ -533,8 +533,8 @@ void KMTransportDialog::makeSmtpPage()
   TQHBoxLayout *buttonLay = new TQHBoxLayout( vlay );
   mSmtp.checkCapabilities =
     new TQPushButton( i18n("Check &What the Server Supports"), page2 );
-  connect(mSmtp.checkCapabilities, TQT_SIGNAL(clicked()),
-    TQT_SLOT(slotCheckSmtpCapabilities()));
+  connect(mSmtp.checkCapabilities, TQ_SIGNAL(clicked()),
+    TQ_SLOT(slotCheckSmtpCapabilities()));
   buttonLay->addStretch();
   buttonLay->addWidget( mSmtp.checkCapabilities );
 }
@@ -720,11 +720,11 @@ void KMTransportDialog::slotCheckSmtpCapabilities()
   mServerTest = new KMServerTest(SMTP_PROTOCOL, mSmtp.hostEdit->text(),
     mSmtp.portEdit->text().toInt());
   connect( mServerTest,
-           TQT_SIGNAL( capabilities( const TQStringList &, const TQStringList &,
+           TQ_SIGNAL( capabilities( const TQStringList &, const TQStringList &,
                                  const TQString &, const TQString &,
                                  const TQString & )),
            this,
-           TQT_SLOT( slotSmtpCapabilities( const TQStringList &,
+           TQ_SLOT( slotSmtpCapabilities( const TQStringList &,
                                        const TQStringList &, const TQString &,
                                        const TQString &, const TQString & ) ) );
   mSmtp.checkCapabilities->setEnabled(false);
