@@ -24,7 +24,7 @@
 #define KONTACT_CORE_H
 
 #include <tqdatetime.h>
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 #include <tdeparts/mainwindow.h>
 #include <tdeparts/part.h>
 
@@ -40,7 +40,7 @@ class Plugin;
 */
 class KDE_EXPORT Core : public KParts::MainWindow
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     virtual ~Core();
