@@ -54,11 +54,11 @@ KCMKOrgSummary::KCMKOrgSummary( TQWidget *parent, const char *name )
 
   customDaysChanged( 1 );
 
-  connect( mCalendarGroup, TQT_SIGNAL( clicked( int ) ), TQT_SLOT( modified() ) );
-  connect( mCalendarGroup, TQT_SIGNAL( clicked( int ) ), TQT_SLOT( buttonClicked( int ) ) );
-  connect( mTodoGroup, TQT_SIGNAL( clicked( int ) ), TQT_SLOT( modified() ) );
-  connect( mCustomDays, TQT_SIGNAL( valueChanged( int ) ), TQT_SLOT( modified() ) );
-  connect( mCustomDays, TQT_SIGNAL( valueChanged( int ) ), TQT_SLOT( customDaysChanged( int ) ) );
+  connect( mCalendarGroup, TQ_SIGNAL( clicked( int ) ), TQ_SLOT( modified() ) );
+  connect( mCalendarGroup, TQ_SIGNAL( clicked( int ) ), TQ_SLOT( buttonClicked( int ) ) );
+  connect( mTodoGroup, TQ_SIGNAL( clicked( int ) ), TQ_SLOT( modified() ) );
+  connect( mCustomDays, TQ_SIGNAL( valueChanged( int ) ), TQ_SLOT( modified() ) );
+  connect( mCustomDays, TQ_SIGNAL( valueChanged( int ) ), TQ_SLOT( customDaysChanged( int ) ) );
 
   TDEAcceleratorManager::manage( this );
 
@@ -92,7 +92,7 @@ void KCMKOrgSummary::initGUI()
 {
   TQVBoxLayout *layout = new TQVBoxLayout( this, 0, KDialog::spacingHint() );
 
-  mCalendarGroup = new TQButtonGroup( 0, Qt::Vertical, i18n( "Appointments" ), this );
+  mCalendarGroup = new TQButtonGroup( 0, TQt::Vertical, i18n( "Appointments" ), this );
   TQVBoxLayout *boxLayout = new TQVBoxLayout( mCalendarGroup->layout(),
                                             KDialog::spacingHint() );
 
@@ -124,7 +124,7 @@ void KCMKOrgSummary::initGUI()
 
   layout->addWidget( mCalendarGroup );
 
-  mTodoGroup = new TQButtonGroup( 2, Qt::Horizontal, i18n( "To-dos" ), this );
+  mTodoGroup = new TQButtonGroup( 2, TQt::Horizontal, i18n( "To-dos" ), this );
   new TQRadioButton( i18n( "Show all to-dos" ), mTodoGroup );
   new TQRadioButton( i18n( "Show today's to-dos only" ), mTodoGroup );
 
