@@ -79,7 +79,7 @@ class AttachmentListItem : public TDEIconViewItem
       if ( att ) {
         mAttachment = new KCal::Attachment( *att );
       } else {
-        mAttachment = new KCal::Attachment( '\0' ); //use the non-uri constructor
+        mAttachment = new KCal::Attachment( TQChar('\0') ); //use the non-uri constructor
                                                     //as we want inline by default
       }
       readAttachment();
@@ -189,7 +189,7 @@ AttachmentEditDialog::AttachmentEditDialog( AttachmentListItem *item,
                    i18n( "Type any string you desire here for the name of the attachment" ) );
   grid->addMultiCellWidget( mLabelEdit, 0, 0, 1, 2 );
 
-  KSeparator *sep = new KSeparator( Qt::Horizontal, topFrame );
+  KSeparator *sep = new KSeparator( TQt::Horizontal, topFrame );
   grid->addMultiCellWidget( sep, 1, 1, 0, 2 );
 
   TQLabel *label = new TQLabel( i18n( "Type:" ), topFrame );
@@ -224,10 +224,10 @@ AttachmentEditDialog::AttachmentEditDialog( AttachmentListItem *item,
       i18n( "Enter the path to the attachment file or use the "
             "file browser by pressing the adjacent button" ) );
     grid->addMultiCellWidget( mURLRequester, 4, 4, 1, 2 );
-    connect( mURLRequester, TQT_SIGNAL(urlSelected(const TQString &)),
-             TQT_SLOT(urlSelected(const TQString &)) );
-    connect( mURLRequester, TQT_SIGNAL( textChanged( const TQString& ) ),
-             TQT_SLOT( urlChanged( const TQString& ) ) );
+    connect( mURLRequester, TQ_SIGNAL(urlSelected(const TQString &)),
+             TQ_SLOT(urlSelected(const TQString &)) );
+    connect( mURLRequester, TQ_SIGNAL( textChanged( const TQString& ) ),
+             TQ_SLOT( urlChanged( const TQString& ) ) );
     urlChanged( item->uri() );
   } else {
     uint size = item->attachment()->size();
@@ -324,8 +324,8 @@ AttachmentIconView::AttachmentIconView( KOEditorAttachments* parent )
   setMaxItemWidth( TQMAX(maxItemWidth(), 250) );
   setMinimumHeight( TQMAX(fontMetrics().height(), 16) + 12 );
 
-  connect( this, TQT_SIGNAL( dropped ( TQDropEvent *, const TQValueList<TQIconDragItem> & ) ),
-           this, TQT_SLOT( handleDrop( TQDropEvent *, const TQValueList<TQIconDragItem> & ) ) );
+  connect( this, TQ_SIGNAL( dropped ( TQDropEvent *, const TQValueList<TQIconDragItem> & ) ),
+           this, TQ_SLOT( handleDrop( TQDropEvent *, const TQValueList<TQIconDragItem> & ) ) );
 }
 
 KURL AttachmentIconView::tempFileForAttachment( KCal::Attachment *attachment )
@@ -462,12 +462,12 @@ KOEditorAttachments::KOEditorAttachments( int spacing, TQWidget *parent,
                    i18n("Displays a list of current items (files, mail, etc.) "
                         "that have been associated with this event or to-do. ") );
   topLayout->addWidget( mAttachments );
-  connect( mAttachments, TQT_SIGNAL( doubleClicked( TQIconViewItem * ) ),
-           TQT_SLOT( showAttachment( TQIconViewItem * ) ) );
-  connect( mAttachments, TQT_SIGNAL(selectionChanged()),
-           TQT_SLOT(selectionChanged()) );
-  connect( mAttachments, TQT_SIGNAL(contextMenuRequested(TQIconViewItem*,const TQPoint&)),
-           TQT_SLOT(contextMenu(TQIconViewItem*,const TQPoint&)) );
+  connect( mAttachments, TQ_SIGNAL( doubleClicked( TQIconViewItem * ) ),
+           TQ_SLOT( showAttachment( TQIconViewItem * ) ) );
+  connect( mAttachments, TQ_SIGNAL(selectionChanged()),
+           TQ_SLOT(selectionChanged()) );
+  connect( mAttachments, TQ_SIGNAL(contextMenuRequested(TQIconViewItem*,const TQPoint&)),
+           TQ_SLOT(contextMenu(TQIconViewItem*,const TQPoint&)) );
 
     TQPushButton *addButton = new TQPushButton( this );
   addButton->setIconSet( SmallIconSet( "add" ) );
@@ -477,7 +477,7 @@ KOEditorAttachments::KOEditorAttachments( int spacing, TQWidget *parent,
                          "to add to this event or to-do as link or as "
                          "inline data." ) );
   topLayout->addWidget( addButton );
-  connect( addButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotAdd()) );
+  connect( addButton, TQ_SIGNAL(clicked()), TQ_SLOT(slotAdd()) );
 
   mRemoveBtn = new TQPushButton( this );
   mRemoveBtn->setIconSet( SmallIconSet( "remove" ) );
@@ -486,33 +486,33 @@ KOEditorAttachments::KOEditorAttachments( int spacing, TQWidget *parent,
                    i18n("Removes the attachment selected in the list above "
                         "from this event or to-do.") );
   topLayout->addWidget( mRemoveBtn );
-  connect( mRemoveBtn, TQT_SIGNAL(clicked()), TQT_SLOT(slotRemove()) );
+  connect( mRemoveBtn, TQ_SIGNAL(clicked()), TQ_SLOT(slotRemove()) );
 
   mContextMenu = new TDEPopupMenu( this );
 
-  TDEActionCollection* ac = new TDEActionCollection( TQT_TQWIDGET(this), TQT_TQOBJECT(this) );
+  TDEActionCollection* ac = new TDEActionCollection( this, this );
 
-  mOpenAction = new TDEAction( i18n("Open"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotShow()), ac );
+  mOpenAction = new TDEAction( i18n("Open"), 0, this, TQ_SLOT(slotShow()), ac );
   mOpenAction->plug( mContextMenu );
 
-  mSaveAsAction = new TDEAction( i18n( "Save As..." ), 0, TQT_TQOBJECT(this), TQT_SLOT(slotSaveAs()), ac );
+  mSaveAsAction = new TDEAction( i18n( "Save As..." ), 0, this, TQ_SLOT(slotSaveAs()), ac );
   mSaveAsAction->plug( mContextMenu );
   mContextMenu->insertSeparator();
 
-  mCopyAction = KStdAction::copy(TQT_TQOBJECT(this), TQT_SLOT(slotCopy()), ac );
+  mCopyAction = KStdAction::copy(this, TQ_SLOT(slotCopy()), ac );
   mCopyAction->plug( mContextMenu );
-  mCutAction = KStdAction::cut(TQT_TQOBJECT(this), TQT_SLOT(slotCut()), ac );
+  mCutAction = KStdAction::cut(this, TQ_SLOT(slotCut()), ac );
   mCutAction->plug( mContextMenu );
-  TDEAction *action = KStdAction::paste(TQT_TQOBJECT(this), TQT_SLOT(slotPaste()), ac );
+  TDEAction *action = KStdAction::paste(this, TQ_SLOT(slotPaste()), ac );
   action->plug( mContextMenu );
   mContextMenu->insertSeparator();
 
-  mDeleteAction = new TDEAction( i18n( "&Remove" ), 0, TQT_TQOBJECT(this), TQT_SLOT(slotRemove()),  ac );
+  mDeleteAction = new TDEAction( i18n( "&Remove" ), 0, this, TQ_SLOT(slotRemove()),  ac );
   mDeleteAction->plug( mContextMenu );
   mDeleteAction->setShortcut( Key_Delete );
   mContextMenu->insertSeparator();
 
-  mEditAction = new TDEAction( i18n( "&Properties..." ), 0, TQT_TQOBJECT(this), TQT_SLOT(slotEdit()), ac );
+  mEditAction = new TDEAction( i18n( "&Properties..." ), 0, this, TQ_SLOT(slotEdit()), ac );
   mEditAction->plug( mContextMenu );
 
   selectionChanged();
@@ -691,7 +691,7 @@ void KOEditorAttachments::slotEdit()
       AttachmentEditDialog *dialog = new AttachmentEditDialog( attitem, mAttachments );
       dialog->mInline->setEnabled( false );
       dialog->setModal( false );
-      connect( dialog, TQT_SIGNAL(hidden()), dialog, TQT_SLOT(delayedDestruct()) );
+      connect( dialog, TQ_SIGNAL(hidden()), dialog, TQ_SLOT(delayedDestruct()) );
       dialog->show();
     }
   }
@@ -854,7 +854,7 @@ void KOEditorAttachments::readIncidence( KCal::Incidence *i )
     addAttachment( (*it) );
   }
   if ( mAttachments->count() > 0 ) {
-    TQTimer::singleShot( 0, mAttachments, TQT_SLOT(arrangeItemsInGrid()) );
+    TQTimer::singleShot( 0, mAttachments, TQ_SLOT(arrangeItemsInGrid()) );
   }
 }
 
