@@ -30,7 +30,7 @@
 
 #include <tqdatetime.h>
 #include <kprinter.h>
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 #include <libkcal/calendar.h>
 #include <libkcal/event.h>
 #include <libkcal/todo.h>
