@@ -65,7 +65,7 @@ class LIBKCAL_EXPORT CalendarResources :
       public Calendar,
       public KRES::ManagerObserver<ResourceCalendar>
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     /**
