@@ -34,7 +34,7 @@ namespace GpgME {
 namespace QGpgME {
 
   class KDE_EXPORT EventLoopInteractor : public TQObject, public GpgME::EventLoopInteractor {
-    Q_OBJECT
+    TQ_OBJECT
   
   protected:
     EventLoopInteractor( TQObject * parent, const char * name=0 );
