@@ -37,7 +37,7 @@ namespace KParts
    **/
 	class KDE_EXPORT InfoExtension : public TQObject
 	{
-		Q_OBJECT
+		TQ_OBJECT
   
 
 	public:
