@@ -187,7 +187,7 @@ class KDE_EXPORT GroupItem : public TQCheckListItem
 
 class KDE_EXPORT KSubscription : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
