@@ -33,7 +33,7 @@ namespace TDEABC {
 
 class KDE_EXPORT ResourceCached : public Resource
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
