@@ -43,7 +43,7 @@ class CalDavWriter;
  */
 class KDE_EXPORT ResourceCalDav : public ResourceCached
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
