@@ -39,7 +39,7 @@ class EGroupwarePrefs;
 
 class KDE_EXPORT ResourceXMLRPC : public ResourceCached
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
@@ -91,8 +91,8 @@ class KDE_EXPORT ResourceXMLRPC : public ResourceCached
 
     TQString addrTypesToTypeStr( int );
 
-    void writeContact( const Addressee&, TQMap<TQString, TQVariant>& );
-    void readContact( const TQMap<TQString, TQVariant>&, Addressee &addr, TQString& );
+    void writeContact( const Addressee&, TQStringVariantMap& );
+    void readContact( const TQStringVariantMap&, Addressee &addr, TQString& );
 
     EGroupwarePrefs *mPrefs;
 
