@@ -39,7 +39,7 @@ namespace KCal {
 */
 class KDE_EXPORT ResourceFeaturePlan : public ResourceCached
 {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     ResourceFeaturePlan( const TDEConfig * );
