@@ -33,7 +33,7 @@ namespace KCal {
 */
 class KDE_EXPORT ResourceGroupDav : public ResourceGroupwareBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     ResourceGroupDav();
