@@ -43,7 +43,7 @@ class GroupwisePrefsBase;
 */
 class KDE_EXPORT ResourceGroupwise : public ResourceCached
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
