@@ -295,14 +295,14 @@ void Groupwise::getAddressbook( const KURL &url )
 
     GroupwiseServer server( u, user, pass, 0 );
 
-    connect( &server, TQT_SIGNAL( readAddressBookTotalSize( int ) ),
-      TQT_SLOT( slotReadAddressBookTotalSize( int ) ) );
-    connect( &server, TQT_SIGNAL( readAddressBookProcessedSize( int ) ),
-      TQT_SLOT( slotReadAddressBookProcessedSize( int ) ) );
-    connect( &server, TQT_SIGNAL( errorMessage( const TQString &, bool ) ),
-      TQT_SLOT( slotServerErrorMessage( const TQString &, bool ) ) );
-    connect( &server, TQT_SIGNAL( gotAddressees( const TDEABC::Addressee::List ) ),
-      TQT_SLOT( slotReadReceiveAddressees( const TDEABC::Addressee::List ) ) );
+    connect( &server, TQ_SIGNAL( readAddressBookTotalSize( int ) ),
+      TQ_SLOT( slotReadAddressBookTotalSize( int ) ) );
+    connect( &server, TQ_SIGNAL( readAddressBookProcessedSize( int ) ),
+      TQ_SLOT( slotReadAddressBookProcessedSize( int ) ) );
+    connect( &server, TQ_SIGNAL( errorMessage( const TQString &, bool ) ),
+      TQ_SLOT( slotServerErrorMessage( const TQString &, bool ) ) );
+    connect( &server, TQ_SIGNAL( gotAddressees( const TDEABC::Addressee::List ) ),
+      TQ_SLOT( slotReadReceiveAddressees( const TDEABC::Addressee::List ) ) );
 
     kdDebug() << "Login" << endl;
     if ( !server.login() ) {
@@ -369,10 +369,10 @@ void Groupwise::updateAddressbook( const KURL &url )
     debugMessage( "update IDs: " + ids.join( "," ) );
 
     GroupwiseServer server( u, user, pass, 0 );
-    connect( &server, TQT_SIGNAL( errorMessage( const TQString &, bool ) ),
-      TQT_SLOT( slotServerErrorMessage( const TQString &, bool ) ) );
-    connect( &server, TQT_SIGNAL( gotAddressees( const TDEABC::Addressee::List ) ),
-      TQT_SLOT( slotReadReceiveAddressees( const TDEABC::Addressee::List ) ) );
+    connect( &server, TQ_SIGNAL( errorMessage( const TQString &, bool ) ),
+      TQ_SLOT( slotServerErrorMessage( const TQString &, bool ) ) );
+    connect( &server, TQ_SIGNAL( gotAddressees( const TDEABC::Addressee::List ) ),
+      TQ_SLOT( slotReadReceiveAddressees( const TDEABC::Addressee::List ) ) );
 
     kdDebug() << "  Login" << endl;
     if ( !server.login() ) {
