@@ -51,7 +51,7 @@ class CalendarAdaptor;
 */
 class KDE_EXPORT ResourceGroupwareBase : public ResourceCached
 {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     ResourceGroupwareBase();
