@@ -31,7 +31,7 @@ namespace KCal {
 */
 class KDE_EXPORT ResourceExchange : public ResourceGroupwareBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     ResourceExchange();
