@@ -60,7 +60,7 @@ class SloxAccounts;
 */
 class KDE_EXPORT KCalResourceSlox : public KCal::ResourceCached, public SloxBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     friend class KCalResourceSloxConfig;
