@@ -44,7 +44,7 @@ class SloxBase;
 */
 class KDE_EXPORT KCalResourceSloxConfig : public KRES::ConfigWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     KCalResourceSloxConfig( TQWidget *parent = 0, const char *name = 0 );
