@@ -50,7 +50,7 @@ class TVAnytimePrefsBase;
 */
 class KDE_EXPORT ResourceTVAnytime : public ResourceCached
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
